//   MoleKing //
//
//   File:        [OPLSff.cpp]
//
//   Author(s):   ['LEEDMOL Reserch Group']
//   Site(s):     ['https://www.researchgate.net/lab/LEEDMOL-Heibbe-Cristhians-Research-Group-Heibbe-Cristhian-B-De-Oliveira']
//   Email(s):    ['heibbe@ufg.br']
//   Credits:     ['Copyright © 2023 LEEDMOL. All rights reserved.']
//   Date:        ['17.01.2023']
//   Version:     ['1.5.3']
//   Status:      ['Development']
//   Language:    ['C++','Python']
//   Description: ['A python module written in C++ for theoretical chemestry']

#include "OPLSff.hpp"

OPLSff::OPLSff(){
    //OPLS Bond Type
    this->opls.insert(pair<string, string>("opls_001" ,  "C" ));
    this->opls.insert(pair<string, string>("opls_002" ,  "O" ));
    this->opls.insert(pair<string, string>("opls_003" ,  "N" ));
    this->opls.insert(pair<string, string>("opls_004" ,  "H" ));
    this->opls.insert(pair<string, string>("opls_005" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_006" ,  "CH"));
    this->opls.insert(pair<string, string>("opls_007" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_008" ,  "CH"));
    this->opls.insert(pair<string, string>("opls_009" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_010" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_011" ,  "CD"));
    this->opls.insert(pair<string, string>("opls_012" ,  "N" ));
    this->opls.insert(pair<string, string>("opls_013" ,  "H" ));
    this->opls.insert(pair<string, string>("opls_014" ,  "CH"));
    this->opls.insert(pair<string, string>("opls_015" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_016" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_017" ,  "C" ));
    this->opls.insert(pair<string, string>("opls_018" ,  "O2"));
    this->opls.insert(pair<string, string>("opls_019" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_020" ,  "N3"));
    this->opls.insert(pair<string, string>("opls_021" ,  "H3"));
    this->opls.insert(pair<string, string>("opls_022" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_023" ,  "OH"));
    this->opls.insert(pair<string, string>("opls_024" ,  "HO"));
    this->opls.insert(pair<string, string>("opls_025" ,  "CH"));
    this->opls.insert(pair<string, string>("opls_026" ,  "C" ));
    this->opls.insert(pair<string, string>("opls_027" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_028" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_029" ,  "CH"));
    this->opls.insert(pair<string, string>("opls_030" ,  "CH"));
    this->opls.insert(pair<string, string>("opls_031" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_032" ,  "SH"));
    this->opls.insert(pair<string, string>("opls_033" ,  "HS"));
    this->opls.insert(pair<string, string>("opls_034" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_035" ,  "S" ));
    this->opls.insert(pair<string, string>("opls_036" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_037" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_038" ,  "S" ));
    this->opls.insert(pair<string, string>("opls_039" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_040" ,  "NA"));
    this->opls.insert(pair<string, string>("opls_041" ,  "H" ));
    this->opls.insert(pair<string, string>("opls_042" ,  "NB"));
    this->opls.insert(pair<string, string>("opls_043" ,  "CP"));
    this->opls.insert(pair<string, string>("opls_044" ,  "CF"));
    this->opls.insert(pair<string, string>("opls_045" ,  "CC"));
    this->opls.insert(pair<string, string>("opls_046" ,  "NA"));
    this->opls.insert(pair<string, string>("opls_047" ,  "H" ));
    this->opls.insert(pair<string, string>("opls_048" ,  "CP"));
    this->opls.insert(pair<string, string>("opls_049" ,  "CG"));
    this->opls.insert(pair<string, string>("opls_050" ,  "CB"));
    this->opls.insert(pair<string, string>("opls_051" ,  "N2"));
    this->opls.insert(pair<string, string>("opls_052" ,  "H3"));
    this->opls.insert(pair<string, string>("opls_053" ,  "CA"));
    this->opls.insert(pair<string, string>("opls_054" ,  "N2"));
    this->opls.insert(pair<string, string>("opls_055" ,  "H3"));
    this->opls.insert(pair<string, string>("opls_056" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_057" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_058" ,  "C" ));
    this->opls.insert(pair<string, string>("opls_059" ,  "O" ));
    this->opls.insert(pair<string, string>("opls_060" ,  "CH"));
    this->opls.insert(pair<string, string>("opls_061" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_062" ,  "OS"));
    this->opls.insert(pair<string, string>("opls_063" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_064" ,  "CT"));
    this->opls.insert(pair<string, string>("opls_065" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_066" ,  "C4"));
    this->opls.insert(pair<string, string>("opls_067" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_068" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_069" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_070" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_071" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_072" ,  "C9"));
    this->opls.insert(pair<string, string>("opls_073" ,  "CH"));
    this->opls.insert(pair<string, string>("opls_074" ,  "C8"));
    this->opls.insert(pair<string, string>("opls_075" ,  "CD"));
    this->opls.insert(pair<string, string>("opls_076" ,  "CT"));
    this->opls.insert(pair<string, string>("opls_077" ,  "C7"));
    this->opls.insert(pair<string, string>("opls_078" ,  "OH"));
    this->opls.insert(pair<string, string>("opls_079" ,  "HO"));
    this->opls.insert(pair<string, string>("opls_080" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_081" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_082" ,  "SH"));
    this->opls.insert(pair<string, string>("opls_083" ,  "SH"));
    this->opls.insert(pair<string, string>("opls_084" ,  "S" ));
    this->opls.insert(pair<string, string>("opls_085" ,  "S" ));
    this->opls.insert(pair<string, string>("opls_086" ,  "HS"));
    this->opls.insert(pair<string, string>("opls_087" ,  "HS"));
    this->opls.insert(pair<string, string>("opls_088" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_089" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_090" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_091" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_092" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_093" ,  "C2"));
    this->opls.insert(pair<string, string>("opls_094" ,  "N" ));
    this->opls.insert(pair<string, string>("opls_095" ,  "C" ));
    this->opls.insert(pair<string, string>("opls_096" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_097" ,  "Ar"));
    this->opls.insert(pair<string, string>("opls_098" ,  "Kr"));
    this->opls.insert(pair<string, string>("opls_099" ,  "Xe"));
    this->opls.insert(pair<string, string>("opls_101" ,  "N3"));
    this->opls.insert(pair<string, string>("opls_102" ,  "N3"));
    this->opls.insert(pair<string, string>("opls_103" ,  "N3"));
    this->opls.insert(pair<string, string>("opls_104" ,  "H3"));
    this->opls.insert(pair<string, string>("opls_105" ,  "H3"));
    this->opls.insert(pair<string, string>("opls_106" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_107" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_108" ,  "OS"));
    this->opls.insert(pair<string, string>("opls_109" ,  "C3"));
    this->opls.insert(pair<string, string>("opls_110" ,  "C2"));
    //(water)
    this->opls.insert(pair<string, string>("opls_111" ,  "OW"));
    this->opls.insert(pair<string, string>("opls_112" ,  "HW"));
    this->opls.insert(pair<string, string>("opls_113" ,  "OW"));
    this->opls.insert(pair<string, string>("opls_114" ,  "HW"));
    this->opls.insert(pair<string, string>("opls_115" ,  "MW"));
    this->opls.insert(pair<string, string>("opls_116" ,  "OW"));
    this->opls.insert(pair<string, string>("opls_117" ,  "HW"));
    this->opls.insert(pair<string, string>("opls_118" ,  "OW"));
    this->opls.insert(pair<string, string>("opls_118e",  "OW"));
    this->opls.insert(pair<string, string>("opls_119" ,  "HW"));
    //water 
    this->opls.insert(pair<string, string>("opls_120" ,  "OL")); 
    this->opls.insert(pair<string, string>("opls_122" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_123" ,  "Cl")); 
    this->opls.insert(pair<string, string>("opls_124" ,  "S" ));
    this->opls.insert(pair<string, string>("opls_125" ,  "O2")); 
    this->opls.insert(pair<string, string>("opls_126" ,  "C3")); 
    this->opls.insert(pair<string, string>("opls_127" ,  "NT")); 
    this->opls.insert(pair<string, string>("opls_128" ,  "H" ));
    this->opls.insert(pair<string, string>("opls_129" ,  "Ne")); 
    this->opls.insert(pair<string, string>("opls_130" ,  "He")); 
    this->opls.insert(pair<string, string>("opls_131" ,  "C" ));
    this->opls.insert(pair<string, string>("opls_132" ,  "C3")); 
    this->opls.insert(pair<string, string>("opls_135" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_136" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_137" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_138" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_139" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_140" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_141" ,  "CM")); 
    this->opls.insert(pair<string, string>("opls_142" ,  "CM")); 
    this->opls.insert(pair<string, string>("opls_143" ,  "CM")); 
    this->opls.insert(pair<string, string>("opls_144" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_145" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_145B",  "C!")); 
    this->opls.insert(pair<string, string>("opls_146" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_147" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_148" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_149" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_150" ,  "C=")); 
    this->opls.insert(pair<string, string>("opls_151" ,  "Cl")); 
    this->opls.insert(pair<string, string>("opls_152" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_153" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_154" ,  "OH")); 
    this->opls.insert(pair<string, string>("opls_155" ,  "HO")); 
    this->opls.insert(pair<string, string>("opls_156" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_157" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_158" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_159" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_160" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_161" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_162" ,  "OH")); 
    this->opls.insert(pair<string, string>("opls_163" ,  "HO")); 
    this->opls.insert(pair<string, string>("opls_164" ,  "F" )); 
    this->opls.insert(pair<string, string>("opls_165" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_166" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_167" ,  "OH")); 
    this->opls.insert(pair<string, string>("opls_168" ,  "HO")); 
    this->opls.insert(pair<string, string>("opls_169" ,  "OH")); 
    this->opls.insert(pair<string, string>("opls_170" ,  "HO")); 
    this->opls.insert(pair<string, string>("opls_171" ,  "OH")); 
    this->opls.insert(pair<string, string>("opls_172" ,  "HO")); 
    this->opls.insert(pair<string, string>("opls_173" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_174" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_175" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_176" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_178" ,  "C=")); 
    this->opls.insert(pair<string, string>("opls_179" ,  "OS")); 
    this->opls.insert(pair<string, string>("opls_180" ,  "OS")); 
    this->opls.insert(pair<string, string>("opls_181" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_182" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_183" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_184" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_185" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_186" ,  "OS")); 
    this->opls.insert(pair<string, string>("opls_187" ,  "OH")); 
    this->opls.insert(pair<string, string>("opls_188" ,  "HO")); 
    this->opls.insert(pair<string, string>("opls_189" ,  "CO")); 
    this->opls.insert(pair<string, string>("opls_190" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_191" ,  "CO")); 
    this->opls.insert(pair<string, string>("opls_192" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_193" ,  "CO")); 
    this->opls.insert(pair<string, string>("opls_194" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_195" ,  "CO")); 
    this->opls.insert(pair<string, string>("opls_196" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_197" ,  "CO")); 
    this->opls.insert(pair<string, string>("opls_198" ,  "CO")); 
    this->opls.insert(pair<string, string>("opls_199" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_200" ,  "SH")); 
    this->opls.insert(pair<string, string>("opls_201" ,  "SH")); 
    this->opls.insert(pair<string, string>("opls_202" ,  "S" )); 
    this->opls.insert(pair<string, string>("opls_203" ,  "S" )); 
    this->opls.insert(pair<string, string>("opls_204" ,  "HS")); 
    this->opls.insert(pair<string, string>("opls_205" ,  "HS")); 
    this->opls.insert(pair<string, string>("opls_206" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_207" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_208" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_209" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_210" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_211" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_212" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_213" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_214" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_215" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_216" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_217" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_218" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_219" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_220" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_221" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_222" ,  "S" )); 
    this->opls.insert(pair<string, string>("opls_223" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_223B",  "CT")); 
    this->opls.insert(pair<string, string>("opls_224" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_224B",  "CT")); 
    this->opls.insert(pair<string, string>("opls_225" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_225B",  "CT")); 
    this->opls.insert(pair<string, string>("opls_226" ,  "Cl")); 
    this->opls.insert(pair<string, string>("opls_227" ,  "CM")); 
    this->opls.insert(pair<string, string>("opls_228" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_229" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_230" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_231" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_232" ,  "C_")); 
    this->opls.insert(pair<string, string>("opls_233" ,  "C_")); 
    this->opls.insert(pair<string, string>("opls_234" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_235" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_236" ,  "O" )); 
    this->opls.insert(pair<string, string>("opls_237" ,  "N" )); 
    this->opls.insert(pair<string, string>("opls_238" ,  "N" )); 
    this->opls.insert(pair<string, string>("opls_239" ,  "N" )); 
    this->opls.insert(pair<string, string>("opls_240" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_241" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_242" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_243" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_244" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_245" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_246" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_247" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_248" ,  "O" )); 
    this->opls.insert(pair<string, string>("opls_249" ,  "N" )); 
    this->opls.insert(pair<string, string>("opls_250" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_251" ,  "N" )); 
    this->opls.insert(pair<string, string>("opls_252" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_253" ,  "O" )); 
    this->opls.insert(pair<string, string>("opls_254" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_255" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_256" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_257" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_258" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_259" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_260" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_261" ,  "CZ")); 
    this->opls.insert(pair<string, string>("opls_262" ,  "NZ")); 
    this->opls.insert(pair<string, string>("opls_263" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_264" ,  "Cl")); 
    this->opls.insert(pair<string, string>("opls_265" ,  "N" )); 
    this->opls.insert(pair<string, string>("opls_266" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_267" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_268" ,  "OH")); 
    this->opls.insert(pair<string, string>("opls_269" ,  "O_")); 
    this->opls.insert(pair<string, string>("opls_270" ,  "HO")); 
    this->opls.insert(pair<string, string>("opls_271" ,  "C_")); 
    this->opls.insert(pair<string, string>("opls_272" ,  "O2")); 
    this->opls.insert(pair<string, string>("opls_273" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_274" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_275" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_276" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_277" ,  "C_")); 
    this->opls.insert(pair<string, string>("opls_278" ,  "O_")); 
    this->opls.insert(pair<string, string>("opls_279" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_280" ,  "C_")); 
    this->opls.insert(pair<string, string>("opls_281" ,  "O_")); 
    this->opls.insert(pair<string, string>("opls_282" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_283" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_284" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_285" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_286" ,  "N3")); 
    this->opls.insert(pair<string, string>("opls_287" ,  "N3")); 
    this->opls.insert(pair<string, string>("opls_288" ,  "N3")); 
    this->opls.insert(pair<string, string>("opls_289" ,  "H3")); 
    this->opls.insert(pair<string, string>("opls_290" ,  "H3")); 
    this->opls.insert(pair<string, string>("opls_291" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_292" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_292B",  "CT")); 
    this->opls.insert(pair<string, string>("opls_293" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_293B",  "CT")); 
    this->opls.insert(pair<string, string>("opls_294" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_295" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_296" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_297" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_298" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_299" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_300" ,  "N2")); 
    this->opls.insert(pair<string, string>("opls_301" ,  "H3")); 
    this->opls.insert(pair<string, string>("opls_302" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_303" ,  "N2")); 
    this->opls.insert(pair<string, string>("opls_304" ,  "H3")); 
    this->opls.insert(pair<string, string>("opls_305" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_306" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_307" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_308" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_309" ,  "N3")); 
    this->opls.insert(pair<string, string>("opls_310" ,  "H3")); 
    this->opls.insert(pair<string, string>("opls_311" ,  "NC")); 
    this->opls.insert(pair<string, string>("opls_312" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_313" ,  "N2")); 
    this->opls.insert(pair<string, string>("opls_314" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_315" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_316" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_317" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_318" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_319" ,  "NA")); 
    this->opls.insert(pair<string, string>("opls_319B",  "N*")); 
    this->opls.insert(pair<string, string>("opls_320" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_321" ,  "NA")); 
    this->opls.insert(pair<string, string>("opls_322" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_323" ,  "CM")); 
    this->opls.insert(pair<string, string>("opls_324" ,  "CM")); 
    this->opls.insert(pair<string, string>("opls_325" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_326" ,  "O" )); 
    this->opls.insert(pair<string, string>("opls_327" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_328" ,  "O" )); 
    this->opls.insert(pair<string, string>("opls_329" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_330" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_331" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_332" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_333" ,  "NA")); 
    this->opls.insert(pair<string, string>("opls_333B",  "N*")); 
    this->opls.insert(pair<string, string>("opls_334" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_335" ,  "NC")); 
    this->opls.insert(pair<string, string>("opls_336" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_337" ,  "CM")); 
    this->opls.insert(pair<string, string>("opls_338" ,  "CM")); 
    this->opls.insert(pair<string, string>("opls_339" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_340" ,  "O" )); 
    this->opls.insert(pair<string, string>("opls_341" ,  "N2")); 
    this->opls.insert(pair<string, string>("opls_342" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_343" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_344" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_345" ,  "H4")); 
    this->opls.insert(pair<string, string>("opls_346" ,  "NC")); 
    this->opls.insert(pair<string, string>("opls_347" ,  "CQ")); 
    this->opls.insert(pair<string, string>("opls_348" ,  "NC")); 
    this->opls.insert(pair<string, string>("opls_349" ,  "CB")); 
    this->opls.insert(pair<string, string>("opls_350" ,  "CB")); 
    this->opls.insert(pair<string, string>("opls_351" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_352" ,  "NB")); 
    this->opls.insert(pair<string, string>("opls_353" ,  "CK")); 
    this->opls.insert(pair<string, string>("opls_354" ,  "NA")); 
    this->opls.insert(pair<string, string>("opls_354B",  "N*")); 
    this->opls.insert(pair<string, string>("opls_355" ,  "H5")); 
    this->opls.insert(pair<string, string>("opls_356" ,  "N2")); 
    this->opls.insert(pair<string, string>("opls_357" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_358" ,  "H") ); 
    this->opls.insert(pair<string, string>("opls_359" ,  "H5")); 
    this->opls.insert(pair<string, string>("opls_360" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_361" ,  "NA")); 
    this->opls.insert(pair<string, string>("opls_362" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_363" ,  "NC")); 
    this->opls.insert(pair<string, string>("opls_364" ,  "CB")); 
    this->opls.insert(pair<string, string>("opls_365" ,  "CB")); 
    this->opls.insert(pair<string, string>("opls_366" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_367" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_368" ,  "N2")); 
    this->opls.insert(pair<string, string>("opls_369" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_370" ,  "O" )); 
    this->opls.insert(pair<string, string>("opls_371" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_372" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_373" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_374" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_375" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_376" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_377" ,  "NA")); 
    this->opls.insert(pair<string, string>("opls_377B",  "N*")); 
    this->opls.insert(pair<string, string>("opls_378" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_379" ,  "NA")); 
    this->opls.insert(pair<string, string>("opls_380" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_381" ,  "CM")); 
    this->opls.insert(pair<string, string>("opls_382" ,  "CM")); 
    this->opls.insert(pair<string, string>("opls_383" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_384" ,  "O" )); 
    this->opls.insert(pair<string, string>("opls_385" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_386" ,  "N2")); 
    this->opls.insert(pair<string, string>("opls_387" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_388" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_389" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_390" ,  "H4")); 
    this->opls.insert(pair<string, string>("opls_391" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_392" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_393" ,  "P" )); 
    this->opls.insert(pair<string, string>("opls_394" ,  "O2")); 
    this->opls.insert(pair<string, string>("opls_395" ,  "OS")); 
    this->opls.insert(pair<string, string>("opls_396" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_400" ,  "F-")); 
    this->opls.insert(pair<string, string>("opls_401" ,  "Cl")); 
    this->opls.insert(pair<string, string>("opls_402" ,  "Br")); 
    this->opls.insert(pair<string, string>("opls_403" ,  "I-")); 
    this->opls.insert(pair<string, string>("opls_404" ,  "Li")); 
    this->opls.insert(pair<string, string>("opls_405" ,  "Na")); 
    this->opls.insert(pair<string, string>("opls_406" ,  "Li")); 
    this->opls.insert(pair<string, string>("opls_407" ,  "Na")); 
    this->opls.insert(pair<string, string>("opls_408" ,  "K+")); 
    this->opls.insert(pair<string, string>("opls_409" ,  "Rb")); 
    this->opls.insert(pair<string, string>("opls_410" ,  "Cs")); 
    this->opls.insert(pair<string, string>("opls_411" ,  "Mg")); 
    this->opls.insert(pair<string, string>("opls_412" ,  "Ca")); 
    this->opls.insert(pair<string, string>("opls_413" ,  "Sr")); 
    this->opls.insert(pair<string, string>("opls_414" ,  "Ba")); 
    this->opls.insert(pair<string, string>("opls_415" ,  "C3")); 
    this->opls.insert(pair<string, string>("opls_416" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_417" ,  "SH")); 
    this->opls.insert(pair<string, string>("opls_418" ,  "C3")); 
    this->opls.insert(pair<string, string>("opls_419" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_420" ,  "OH")); 
    this->opls.insert(pair<string, string>("opls_421" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_422" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_423" ,  "CZ")); 
    this->opls.insert(pair<string, string>("opls_424" ,  "NZ")); 
    this->opls.insert(pair<string, string>("opls_425" ,  "C3")); 
    this->opls.insert(pair<string, string>("opls_426" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_427" ,  "N3")); 
    this->opls.insert(pair<string, string>("opls_428" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_429" ,  "C3")); 
    this->opls.insert(pair<string, string>("opls_430" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_431" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_432" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_433" ,  "LP")); 
    this->opls.insert(pair<string, string>("opls_434" ,  "OH")); 
    this->opls.insert(pair<string, string>("opls_435" ,  "HO")); 
    this->opls.insert(pair<string, string>("opls_436" ,  "U" )); 
    this->opls.insert(pair<string, string>("opls_437" ,  "OU")); 
    this->opls.insert(pair<string, string>("opls_440" ,  "P" )); 
    this->opls.insert(pair<string, string>("opls_441" ,  "O2")); 
    this->opls.insert(pair<string, string>("opls_442" ,  "OS")); 
    this->opls.insert(pair<string, string>("opls_443" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_444" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_445" ,  "P" )); 
    this->opls.insert(pair<string, string>("opls_446" ,  "O2")); 
    this->opls.insert(pair<string, string>("opls_447" ,  "OS")); 
    this->opls.insert(pair<string, string>("opls_448" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_449" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_450" ,  "P" )); 
    this->opls.insert(pair<string, string>("opls_451" ,  "O2")); 
    this->opls.insert(pair<string, string>("opls_452" ,  "OS")); 
    this->opls.insert(pair<string, string>("opls_453" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_454" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_455" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_456" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_457" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_458" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_459" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_460" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_461" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_462" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_463" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_465" ,  "C_")); 
    this->opls.insert(pair<string, string>("opls_466" ,  "O_")); 
    this->opls.insert(pair<string, string>("opls_467" ,  "OS")); 
    this->opls.insert(pair<string, string>("opls_468" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_469" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_470" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_471" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_472" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_473" ,  "OS")); 
    this->opls.insert(pair<string, string>("opls_474" ,  "SY")); 
    this->opls.insert(pair<string, string>("opls_475" ,  "OY")); 
    this->opls.insert(pair<string, string>("opls_476" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_477" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_478" ,  "N" )); 
    this->opls.insert(pair<string, string>("opls_479" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_480" ,  "N" )); 
    this->opls.insert(pair<string, string>("opls_481" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_482" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_483" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_484" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_485" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_486" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_487" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_488" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_490" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_491" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_492" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_493" ,  "SY")); 
    this->opls.insert(pair<string, string>("opls_494" ,  "OY")); 
    this->opls.insert(pair<string, string>("opls_496" ,  "SZ")); 
    this->opls.insert(pair<string, string>("opls_497" ,  "OY")); 
    this->opls.insert(pair<string, string>("opls_498" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_499" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_500" ,  "C*")); 
    this->opls.insert(pair<string, string>("opls_501" ,  "CB")); 
    this->opls.insert(pair<string, string>("opls_502" ,  "CN")); 
    this->opls.insert(pair<string, string>("opls_503" ,  "NA")); 
    this->opls.insert(pair<string, string>("opls_504" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_505" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_506" ,  "CR")); 
    this->opls.insert(pair<string, string>("opls_507" ,  "CV")); 
    this->opls.insert(pair<string, string>("opls_508" ,  "CW")); 
    this->opls.insert(pair<string, string>("opls_509" ,  "CR")); 
    this->opls.insert(pair<string, string>("opls_510" ,  "CX")); 
    this->opls.insert(pair<string, string>("opls_511" ,  "NB")); 
    this->opls.insert(pair<string, string>("opls_512" ,  "NA")); 
    this->opls.insert(pair<string, string>("opls_513" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_514" ,  "CW")); 
    this->opls.insert(pair<string, string>("opls_515" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_516" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_517" ,  "CM")); 
    this->opls.insert(pair<string, string>("opls_518" ,  "CM")); 
    this->opls.insert(pair<string, string>("opls_520" ,  "NC")); 
    this->opls.insert(pair<string, string>("opls_521" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_522" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_523" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_524" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_525" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_526" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_527" ,  "NC")); 
    this->opls.insert(pair<string, string>("opls_528" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_529" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_530" ,  "NC")); 
    this->opls.insert(pair<string, string>("opls_531" ,  "CQ")); 
    this->opls.insert(pair<string, string>("opls_532" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_533" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_534" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_535" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_536" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_537" ,  "NC")); 
    this->opls.insert(pair<string, string>("opls_538" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_539" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_540" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_541" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_542" ,  "NA")); 
    this->opls.insert(pair<string, string>("opls_543" ,  "CW")); 
    this->opls.insert(pair<string, string>("opls_544" ,  "CS")); 
    this->opls.insert(pair<string, string>("opls_545" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_546" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_547" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_548" ,  "NA")); 
    this->opls.insert(pair<string, string>("opls_549" ,  "NB")); 
    this->opls.insert(pair<string, string>("opls_550" ,  "CU")); 
    this->opls.insert(pair<string, string>("opls_551" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_552" ,  "CW")); 
    this->opls.insert(pair<string, string>("opls_553" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_554" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_555" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_556" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_557" ,  "NA")); 
    this->opls.insert(pair<string, string>("opls_558" ,  "CR")); 
    this->opls.insert(pair<string, string>("opls_559" ,  "NB")); 
    this->opls.insert(pair<string, string>("opls_560" ,  "CV")); 
    this->opls.insert(pair<string, string>("opls_561" ,  "CW")); 
    this->opls.insert(pair<string, string>("opls_562" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_563" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_564" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_565" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_566" ,  "OS")); 
    this->opls.insert(pair<string, string>("opls_567" ,  "CW")); 
    this->opls.insert(pair<string, string>("opls_568" ,  "CS")); 
    this->opls.insert(pair<string, string>("opls_569" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_570" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_571" ,  "OS")); 
    this->opls.insert(pair<string, string>("opls_572" ,  "CR")); 
    this->opls.insert(pair<string, string>("opls_573" ,  "NB")); 
    this->opls.insert(pair<string, string>("opls_574" ,  "CV")); 
    this->opls.insert(pair<string, string>("opls_575" ,  "CW")); 
    this->opls.insert(pair<string, string>("opls_576" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_577" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_578" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_579" ,  "OS")); 
    this->opls.insert(pair<string, string>("opls_580" ,  "NB")); 
    this->opls.insert(pair<string, string>("opls_581" ,  "CU")); 
    this->opls.insert(pair<string, string>("opls_582" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_583" ,  "CW")); 
    this->opls.insert(pair<string, string>("opls_584" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_585" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_586" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_587" ,  "NA")); 
    this->opls.insert(pair<string, string>("opls_588" ,  "CW")); 
    this->opls.insert(pair<string, string>("opls_589" ,  "CS")); 
    this->opls.insert(pair<string, string>("opls_590" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_591" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_592" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_593" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_594" ,  "CN")); 
    this->opls.insert(pair<string, string>("opls_595" ,  "CB")); 
    this->opls.insert(pair<string, string>("opls_596" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_597" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_598" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_599" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_600" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_601" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_602" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_603" ,  "NC")); 
    this->opls.insert(pair<string, string>("opls_604" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_605" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_606" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_607" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_608" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_609" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_610" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_611" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_612" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_613" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_614" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_615" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_616" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_617" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_618" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_619" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_620" ,  "NC")); 
    this->opls.insert(pair<string, string>("opls_621" ,  "CQ")); 
    this->opls.insert(pair<string, string>("opls_622" ,  "NC")); 
    this->opls.insert(pair<string, string>("opls_623" ,  "CB")); 
    this->opls.insert(pair<string, string>("opls_624" ,  "CB")); 
    this->opls.insert(pair<string, string>("opls_625" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_626" ,  "NB")); 
    this->opls.insert(pair<string, string>("opls_627" ,  "CK")); 
    this->opls.insert(pair<string, string>("opls_628" ,  "NA")); 
    this->opls.insert(pair<string, string>("opls_629" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_630" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_631" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_632" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_633" ,  "S" )); 
    this->opls.insert(pair<string, string>("opls_634" ,  "CR")); 
    this->opls.insert(pair<string, string>("opls_635" ,  "NB")); 
    this->opls.insert(pair<string, string>("opls_636" ,  "CV")); 
    this->opls.insert(pair<string, string>("opls_637" ,  "CW")); 
    this->opls.insert(pair<string, string>("opls_638" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_639" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_640" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_641" ,  "NC")); 
    this->opls.insert(pair<string, string>("opls_642" ,  "CQ")); 
    this->opls.insert(pair<string, string>("opls_643" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_644" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_645" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_646" ,  "NC")); 
    this->opls.insert(pair<string, string>("opls_647" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_648" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_649" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_650" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_651" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_652" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_653" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_654" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_655" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_656" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_670" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_671" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_672" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_673" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_674" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_675" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_676" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_677" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_678" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_679" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_680" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_681" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_697" ,  "Ac")); 
    this->opls.insert(pair<string, string>("opls_698" ,  "Th")); 
    this->opls.insert(pair<string, string>("opls_699" ,  "Am")); 
    this->opls.insert(pair<string, string>("opls_700" ,  "C+")); 
    this->opls.insert(pair<string, string>("opls_701" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_702" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_703" ,  "La")); 
    this->opls.insert(pair<string, string>("opls_704" ,  "Nd")); 
    this->opls.insert(pair<string, string>("opls_705" ,  "Eu")); 
    this->opls.insert(pair<string, string>("opls_706" ,  "Gd")); 
    this->opls.insert(pair<string, string>("opls_707" ,  "Yb")); 
    this->opls.insert(pair<string, string>("opls_708" ,  "CM")); 
    this->opls.insert(pair<string, string>("opls_709" ,  "Cl")); 
    this->opls.insert(pair<string, string>("opls_710" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_711" ,  "CY")); 
    this->opls.insert(pair<string, string>("opls_712" ,  "CY")); 
    this->opls.insert(pair<string, string>("opls_713" ,  "CY")); 
    this->opls.insert(pair<string, string>("opls_714" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_715" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_716" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_717" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_718" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_719" ,  "F" )); 
    this->opls.insert(pair<string, string>("opls_720" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_721" ,  "F" )); 
    this->opls.insert(pair<string, string>("opls_722" ,  "Br")); 
    this->opls.insert(pair<string, string>("opls_724" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_725" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_726" ,  "F" )); 
    this->opls.insert(pair<string, string>("opls_727" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_728" ,  "F" )); 
    this->opls.insert(pair<string, string>("opls_729" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_730" ,  "Br")); 
    this->opls.insert(pair<string, string>("opls_731" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_732" ,  "I" )); 
    this->opls.insert(pair<string, string>("opls_733" ,  "CY")); 
    this->opls.insert(pair<string, string>("opls_734" ,  "SH")); 
    this->opls.insert(pair<string, string>("opls_735" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_736" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_737" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_738" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_739" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_740" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_741" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_742" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_743" ,  "N2")); 
    this->opls.insert(pair<string, string>("opls_744" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_745" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_746" ,  "HA")); 
    this->opls.insert(pair<string, string>("opls_747" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_748" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_749" ,  "NY")); 
    this->opls.insert(pair<string, string>("opls_750" ,  "NZ")); 
    this->opls.insert(pair<string, string>("opls_751" ,  "NY")); 
    this->opls.insert(pair<string, string>("opls_752" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_753" ,  "NZ")); 
    this->opls.insert(pair<string, string>("opls_754" ,  "CZ")); 
    this->opls.insert(pair<string, string>("opls_755" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_756" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_757" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_758" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_759" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_760" ,  "NO")); 
    this->opls.insert(pair<string, string>("opls_761" ,  "ON")); 
    this->opls.insert(pair<string, string>("opls_762" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_763" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_764" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_765" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_766" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_767" ,  "NO")); 
    this->opls.insert(pair<string, string>("opls_768" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_771" ,  "O" )); 
    this->opls.insert(pair<string, string>("opls_772" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_773" ,  "OS")); 
    this->opls.insert(pair<string, string>("opls_774" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_775" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_776" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_777" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_778" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_779" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_781" ,  "P+")); 
    this->opls.insert(pair<string, string>("opls_782" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_783" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_784" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_785" ,  "P" )); 
    this->opls.insert(pair<string, string>("opls_786" ,  "F" )); 
    this->opls.insert(pair<string, string>("opls_787" ,  "N" )); 
    this->opls.insert(pair<string, string>("opls_788" ,  "O" )); 
    this->opls.insert(pair<string, string>("opls_795" ,  "OW")); 
    this->opls.insert(pair<string, string>("opls_796" ,  "HW")); 
    this->opls.insert(pair<string, string>("opls_797" ,  "LP")); 
    this->opls.insert(pair<string, string>("opls_900" ,  "NT")); 
    this->opls.insert(pair<string, string>("opls_901" ,  "NT")); 
    this->opls.insert(pair<string, string>("opls_902" ,  "NT")); 
    this->opls.insert(pair<string, string>("opls_903" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_904" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_905" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_906" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_906B",  "CT")); 
    this->opls.insert(pair<string, string>("opls_907" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_908" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_909" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_910" ,  "H" )); 
    this->opls.insert(pair<string, string>("opls_911" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_912" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_912B",  "CT")); 
    this->opls.insert(pair<string, string>("opls_913" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_914" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_915" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_916" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_917" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_918" ,  "CA")); 
    this->opls.insert(pair<string, string>("opls_925" ,  "CZ")); 
    this->opls.insert(pair<string, string>("opls_926" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_927" ,  "CZ")); 
    this->opls.insert(pair<string, string>("opls_928" ,  "CZ")); 
    this->opls.insert(pair<string, string>("opls_929" ,  "CZ")); 
    this->opls.insert(pair<string, string>("opls_930" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_931" ,  "CZ")); 
    this->opls.insert(pair<string, string>("opls_940" ,  "N3")); 
    this->opls.insert(pair<string, string>("opls_941" ,  "H3")); 
    this->opls.insert(pair<string, string>("opls_942" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_943" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_944" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_945" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_950" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_951" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_952" ,  "C" )); 
    this->opls.insert(pair<string, string>("opls_953" ,  "N3")); 
    this->opls.insert(pair<string, string>("opls_954" ,  "O2")); 
    this->opls.insert(pair<string, string>("opls_955" ,  "H3")); 
    this->opls.insert(pair<string, string>("opls_956" ,  "F" )); 
    this->opls.insert(pair<string, string>("opls_957" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_958" ,  "HC")); 
    this->opls.insert(pair<string, string>("opls_959" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_960" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_961" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_962" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_963" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_964" ,  "CT")); 
    this->opls.insert(pair<string, string>("opls_965" ,  "F" )); 
    // OPLS Epsilons
    this->epsilon.insert(pair<string, double>("opls_001" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_002" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_003" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_004" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_005" ,  4.93712e-01));
    this->epsilon.insert(pair<string, double>("opls_006" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_007" ,  6.69440e-01));
    this->epsilon.insert(pair<string, double>("opls_008" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_009" ,  4.93712e-01));
    this->epsilon.insert(pair<string, double>("opls_010" ,  7.32200e-01));
    this->epsilon.insert(pair<string, double>("opls_011" ,  4.60240e-01));
    this->epsilon.insert(pair<string, double>("opls_012" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_013" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_014" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_015" ,  4.93712e-01));
    this->epsilon.insert(pair<string, double>("opls_016" ,  4.93712e-01));
    this->epsilon.insert(pair<string, double>("opls_017" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_018" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_019" ,  4.93712e-01));
    this->epsilon.insert(pair<string, double>("opls_020" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_021" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_022" ,  4.93712e-01));
    this->epsilon.insert(pair<string, double>("opls_023" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_024" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_025" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_026" ,  4.60240e-01));
    this->epsilon.insert(pair<string, double>("opls_027" ,  4.93712e-01));
    this->epsilon.insert(pair<string, double>("opls_028" ,  4.93712e-01));
    this->epsilon.insert(pair<string, double>("opls_029" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_030" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_031" ,  4.93712e-01));
    this->epsilon.insert(pair<string, double>("opls_032" ,  1.04600e+00));
    this->epsilon.insert(pair<string, double>("opls_033" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_034" ,  4.93712e-01)); 
    this->epsilon.insert(pair<string, double>("opls_035" ,  1.04600e+00));
    this->epsilon.insert(pair<string, double>("opls_035" ,  1.04600e+00)); 
    this->epsilon.insert(pair<string, double>("opls_036" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_037" ,  4.93712e-01)); 
    this->epsilon.insert(pair<string, double>("opls_038" ,  1.04600e+00)); 
    this->epsilon.insert(pair<string, double>("opls_039" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_040" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_041" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_042" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_043" ,  6.06680e-01)); 
    this->epsilon.insert(pair<string, double>("opls_044" ,  6.06680e-01)); 
    this->epsilon.insert(pair<string, double>("opls_045" ,  6.06680e-01)); 
    this->epsilon.insert(pair<string, double>("opls_046" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_047" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_048" ,  6.06680e-01)); 
    this->epsilon.insert(pair<string, double>("opls_049" ,  6.06680e-01)); 
    this->epsilon.insert(pair<string, double>("opls_050" ,  6.06680e-01)); 
    this->epsilon.insert(pair<string, double>("opls_051" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_052" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_053" ,  2.09200e-01)); 
    this->epsilon.insert(pair<string, double>("opls_054" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_055" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_056" ,  4.93712e-01)); 
    this->epsilon.insert(pair<string, double>("opls_057" ,  4.93712e-01)); 
    this->epsilon.insert(pair<string, double>("opls_058" ,  4.39320e-01)); 
    this->epsilon.insert(pair<string, double>("opls_059" ,  8.78640e-01)); 
    this->epsilon.insert(pair<string, double>("opls_060" ,  3.34720e-01)); 
    this->epsilon.insert(pair<string, double>("opls_061" ,  4.93712e-01)); 
    this->epsilon.insert(pair<string, double>("opls_062" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_063" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_064" ,  2.09200e-01)); 
    this->epsilon.insert(pair<string, double>("opls_065" ,  6.06680e-01)); 
    this->epsilon.insert(pair<string, double>("opls_066" ,  1.23010e+00)); 
    this->epsilon.insert(pair<string, double>("opls_067" ,  8.66088e-01)); 
    this->epsilon.insert(pair<string, double>("opls_068" ,  7.32200e-01)); 
    this->epsilon.insert(pair<string, double>("opls_069" ,  6.69440e-01)); 
    this->epsilon.insert(pair<string, double>("opls_070" ,  6.06680e-01)); 
    this->epsilon.insert(pair<string, double>("opls_071" ,  4.93712e-01)); 
    this->epsilon.insert(pair<string, double>("opls_072" ,  5.85760e-01)); 
    this->epsilon.insert(pair<string, double>("opls_073" ,  3.34720e-01)); 
    this->epsilon.insert(pair<string, double>("opls_074" ,  4.81160e-01)); 
    this->epsilon.insert(pair<string, double>("opls_075" ,  4.60240e-01)); 
    this->epsilon.insert(pair<string, double>("opls_076" ,  2.09200e-01)); 
    this->epsilon.insert(pair<string, double>("opls_077" ,  4.39320e-01)); 
    this->epsilon.insert(pair<string, double>("opls_078" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_079" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_080" ,  8.66088e-01)); 
    this->epsilon.insert(pair<string, double>("opls_081" ,  4.93712e-01)); 
    this->epsilon.insert(pair<string, double>("opls_082" ,  1.04600e+00)); 
    this->epsilon.insert(pair<string, double>("opls_083" ,  1.04600e+00)); 
    this->epsilon.insert(pair<string, double>("opls_084" ,  1.04600e+00)); 
    this->epsilon.insert(pair<string, double>("opls_085" ,  1.04600e+00)); 
    this->epsilon.insert(pair<string, double>("opls_086" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_087" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_088" ,  8.66088e-01)); 
    this->epsilon.insert(pair<string, double>("opls_089" ,  4.93712e-01)); 
    this->epsilon.insert(pair<string, double>("opls_090" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_091" ,  4.93712e-01)); 
    this->epsilon.insert(pair<string, double>("opls_092" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_093" ,  4.93712e-01)); 
    this->epsilon.insert(pair<string, double>("opls_094" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_095" ,  6.27600e-01)); 
    this->epsilon.insert(pair<string, double>("opls_096" ,  8.66088e-01)); 
    this->epsilon.insert(pair<string, double>("opls_097" ,  9.78638e-01)); 
    this->epsilon.insert(pair<string, double>("opls_098" ,  1.81167e+00)); 
    this->epsilon.insert(pair<string, double>("opls_099" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_101" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_102" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_103" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_104" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_105" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_106" ,  8.66088e-01)); 
    this->epsilon.insert(pair<string, double>("opls_107" ,  6.06680e-01)); 
    this->epsilon.insert(pair<string, double>("opls_108" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_109" ,  7.11280e-01)); 
    this->epsilon.insert(pair<string, double>("opls_110" ,  4.93712e-01)); 
    this->epsilon.insert(pair<string, double>("opls_111" ,  6.36386e-01));
    this->epsilon.insert(pair<string, double>("opls_112" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_113" ,  6.48520e-01));
    this->epsilon.insert(pair<string, double>("opls_114" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_115" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_116" ,  6.50194e-01));
    this->epsilon.insert(pair<string, double>("opls_117" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_118" ,  6.69440e-01));
    this->epsilon.insert(pair<string, double>("opls_118e",  7.44752e-01));
    this->epsilon.insert(pair<string, double>("opls_119" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_120" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_122" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_123" ,  1.11295e+00));
    this->epsilon.insert(pair<string, double>("opls_124" ,  1.65268e+00));
    this->epsilon.insert(pair<string, double>("opls_125" ,  1.17152e+00));
    this->epsilon.insert(pair<string, double>("opls_126" ,  6.69440e-01));
    this->epsilon.insert(pair<string, double>("opls_127" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_128" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_129" ,  2.88696e-01));
    this->epsilon.insert(pair<string, double>("opls_130" ,  8.36800e-02));
    this->epsilon.insert(pair<string, double>("opls_131" ,  4.81160e-01));
    this->epsilon.insert(pair<string, double>("opls_132" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_135" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_136" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_137" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_138" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_139" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_140" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_141" ,  3.17984e-01));
    this->epsilon.insert(pair<string, double>("opls_142" ,  3.17984e-01));
    this->epsilon.insert(pair<string, double>("opls_143" ,  3.17984e-01));
    this->epsilon.insert(pair<string, double>("opls_144" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_145" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_145B",  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_146" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_147" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_148" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_149" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_150" ,  3.17984e-01));
    this->epsilon.insert(pair<string, double>("opls_151" ,  1.25520e+00));
    this->epsilon.insert(pair<string, double>("opls_152" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_153" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_154" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_155" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_156" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_157" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_158" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_159" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_160" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_161" ,  2.59408e-01));
    this->epsilon.insert(pair<string, double>("opls_162" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_163" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_164" ,  2.55224e-01));
    this->epsilon.insert(pair<string, double>("opls_165" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_166" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_167" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_168" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_169" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_170" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_171" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_172" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_173" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_174" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_175" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_176" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_178" ,  3.17984e-01));
    this->epsilon.insert(pair<string, double>("opls_179" ,  5.85760e-01));
    this->epsilon.insert(pair<string, double>("opls_180" ,  5.85760e-01));
    this->epsilon.insert(pair<string, double>("opls_181" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_182" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_183" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_184" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_185" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_186" ,  5.85760e-01));
    this->epsilon.insert(pair<string, double>("opls_187" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_188" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_189" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_190" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_191" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_192" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_193" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_194" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_195" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_196" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_197" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_198" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_199" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_200" ,  1.77820e+00));
    this->epsilon.insert(pair<string, double>("opls_201" ,  1.04600e+00));
    this->epsilon.insert(pair<string, double>("opls_202" ,  1.48532e+00));
    this->epsilon.insert(pair<string, double>("opls_203" ,  1.04600e+00));
    this->epsilon.insert(pair<string, double>("opls_204" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_205" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_206" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_207" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_208" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_209" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_210" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_211" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_212" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_213" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_214" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_215" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_216" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_217" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_218" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_219" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_220" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_221" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_222" ,  1.04600e+00));
    this->epsilon.insert(pair<string, double>("opls_223" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_223B",  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_224" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_224B",  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_225" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_225B",  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_226" ,  1.25520e+00));
    this->epsilon.insert(pair<string, double>("opls_227" ,  3.17984e-01));
    this->epsilon.insert(pair<string, double>("opls_228" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_229" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_230" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_231" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_232" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_233" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_234" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_235" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_236" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_237" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_238" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_239" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_240" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_241" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_242" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_243" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_244" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_245" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_246" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_247" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_248" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_249" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_250" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_251" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_252" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_253" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_254" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_255" ,  8.36800e-02));
    this->epsilon.insert(pair<string, double>("opls_256" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_257" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_258" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_259" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_260" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_261" ,  6.27600e-01));
    this->epsilon.insert(pair<string, double>("opls_262" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_263" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_264" ,  1.25520e+00));
    this->epsilon.insert(pair<string, double>("opls_265" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_266" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_267" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_268" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_269" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_270" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_271" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_272" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_273" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_274" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_275" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_276" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_277" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_278" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_279" ,  6.27600e-02));
    this->epsilon.insert(pair<string, double>("opls_280" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_281" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_282" ,  6.27600e-02));
    this->epsilon.insert(pair<string, double>("opls_283" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_284" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_285" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_286" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_287" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_288" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_289" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_290" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_291" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_292" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_292B",  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_293" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_293B",  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_294" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_295" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_296" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_297" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_298" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_299" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_300" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_301" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_302" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_303" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_304" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_305" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_306" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_307" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_308" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_309" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_310" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_311" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_312" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_313" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_314" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_315" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_316" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_317" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_318" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_319" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_319B",  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_320" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_321" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_322" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_323" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_324" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_325" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_326" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_327" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_328" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_329" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_330" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_331" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_332" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_333" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_333B",  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_334" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_335" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_336" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_337" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_338" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_339" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_340" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_341" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_342" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_343" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_344" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_345" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_346" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_347" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_348" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_349" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_350" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_351" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_352" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_353" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_354" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_354B",  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_355" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_356" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_357" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_358" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_359" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_360" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_361" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_362" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_363" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_364" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_365" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_366" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_367" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_368" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_369" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_370" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_371" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_372" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_373" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_374" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_375" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_376" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_377" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_377B",  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_378" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_379" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_380" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_381" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_382" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_383" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_384" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_385" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_386" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_387" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_388" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_389" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_390" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_391" ,  3.34720e-01));
    this->epsilon.insert(pair<string, double>("opls_392" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_393" ,  8.36800e-01));
    this->epsilon.insert(pair<string, double>("opls_394" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_395" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_396" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_400" ,  3.01248e+00));
    this->epsilon.insert(pair<string, double>("opls_401" ,  4.92833e-01));
    this->epsilon.insert(pair<string, double>("opls_402" ,  3.76560e-01));
    this->epsilon.insert(pair<string, double>("opls_403" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_404" ,  2.61500e+01));
    this->epsilon.insert(pair<string, double>("opls_405" ,  6.72427e+00));
    this->epsilon.insert(pair<string, double>("opls_406" ,  7.64793e-02));
    this->epsilon.insert(pair<string, double>("opls_407" ,  1.15980e-02));
    this->epsilon.insert(pair<string, double>("opls_408" ,  1.37235e-03));
    this->epsilon.insert(pair<string, double>("opls_409" ,  7.15464e-04));
    this->epsilon.insert(pair<string, double>("opls_410" ,  3.38904e-04));
    this->epsilon.insert(pair<string, double>("opls_411" ,  3.66118e+00));
    this->epsilon.insert(pair<string, double>("opls_412" ,  1.88136e+00));
    this->epsilon.insert(pair<string, double>("opls_413" ,  4.94658e-01));
    this->epsilon.insert(pair<string, double>("opls_414" ,  1.97050e-01));
    this->epsilon.insert(pair<string, double>("opls_415" ,  1.25520e+00));
    this->epsilon.insert(pair<string, double>("opls_416" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_417" ,  2.09200e+00));
    this->epsilon.insert(pair<string, double>("opls_418" ,  1.25520e+00));
    this->epsilon.insert(pair<string, double>("opls_419" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_420" ,  1.04600e+00));
    this->epsilon.insert(pair<string, double>("opls_421" ,  1.25520e+00));
    this->epsilon.insert(pair<string, double>("opls_422" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_423" ,  6.27600e-01));
    this->epsilon.insert(pair<string, double>("opls_424" ,  1.04600e+00));
    this->epsilon.insert(pair<string, double>("opls_425" ,  1.25520e+00));
    this->epsilon.insert(pair<string, double>("opls_426" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_427" ,  1.04600e+00));
    this->epsilon.insert(pair<string, double>("opls_428" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_429" ,  1.25520e+00));
    this->epsilon.insert(pair<string, double>("opls_430" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_431" ,  1.25520e+00));
    this->epsilon.insert(pair<string, double>("opls_432" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_433" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_434" ,  1.04600e+00));
    this->epsilon.insert(pair<string, double>("opls_435" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_436" ,  1.67360e+00));
    this->epsilon.insert(pair<string, double>("opls_437" ,  8.36800e-01));
    this->epsilon.insert(pair<string, double>("opls_440" ,  8.36800e-01));
    this->epsilon.insert(pair<string, double>("opls_441" ,  8.36800e-01));
    this->epsilon.insert(pair<string, double>("opls_442" ,  5.85760e-01));
    this->epsilon.insert(pair<string, double>("opls_443" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_444" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_445" ,  8.36800e-01));
    this->epsilon.insert(pair<string, double>("opls_446" ,  8.36800e-01));
    this->epsilon.insert(pair<string, double>("opls_447" ,  5.85760e-01));
    this->epsilon.insert(pair<string, double>("opls_448" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_449" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_450" ,  8.36800e-01));
    this->epsilon.insert(pair<string, double>("opls_451" ,  8.36800e-01));
    this->epsilon.insert(pair<string, double>("opls_452" ,  5.85760e-01));
    this->epsilon.insert(pair<string, double>("opls_453" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_454" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_455" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_456" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_457" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_458" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_459" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_460" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_461" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_462" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_463" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_465" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_466" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_467" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_468" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_469" ,  6.27600e-02));
    this->epsilon.insert(pair<string, double>("opls_470" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_471" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_472" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_473" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_474" ,  1.04600e+00));
    this->epsilon.insert(pair<string, double>("opls_475" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_476" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_477" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_478" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_479" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_480" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_481" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_482" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_483" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_484" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_485" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_486" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_487" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_488" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_490" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_491" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_492" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_493" ,  1.04600e+00));
    this->epsilon.insert(pair<string, double>("opls_494" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_496" ,  1.65268e+00));
    this->epsilon.insert(pair<string, double>("opls_497" ,  1.17152e+00));
    this->epsilon.insert(pair<string, double>("opls_498" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_499" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_500" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_501" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_502" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_503" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_504" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_505" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_506" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_507" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_508" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_509" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_510" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_511" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_512" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_513" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_514" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_515" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_516" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_517" ,  3.17984e-01));
    this->epsilon.insert(pair<string, double>("opls_518" ,  3.17984e-01));
    this->epsilon.insert(pair<string, double>("opls_520" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_521" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_522" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_523" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_524" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_525" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_526" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_527" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_528" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_529" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_530" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_531" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_532" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_533" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_534" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_535" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_536" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_537" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_538" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_539" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_540" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_541" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_542" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_543" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_544" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_545" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_546" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_547" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_548" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_549" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_550" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_551" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_552" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_553" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_554" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_555" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_556" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_557" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_558" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_559" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_560" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_561" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_562" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_563" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_564" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_565" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_566" ,  5.85760e-01));
    this->epsilon.insert(pair<string, double>("opls_567" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_568" ,  3.17984e-01));
    this->epsilon.insert(pair<string, double>("opls_569" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_570" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_571" ,  5.85760e-01));
    this->epsilon.insert(pair<string, double>("opls_572" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_573" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_574" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_575" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_576" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_577" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_578" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_579" ,  5.85760e-01));
    this->epsilon.insert(pair<string, double>("opls_580" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_581" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_582" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_583" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_584" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_585" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_586" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_587" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_588" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_589" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_590" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_591" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_592" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_593" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_594" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_595" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_596" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_597" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_598" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_599" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_600" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_601" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_602" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_603" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_604" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_605" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_606" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_607" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_608" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_609" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_610" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_611" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_612" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_613" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_614" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_615" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_616" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_617" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_618" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_619" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_620" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_621" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_622" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_623" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_624" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_625" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_626" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_627" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_628" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_629" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_630" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_631" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_632" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_633" ,  1.04600e+00));
    this->epsilon.insert(pair<string, double>("opls_634" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_635" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_636" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_637" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_638" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_639" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_640" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_641" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_642" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_643" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_644" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_645" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_646" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_647" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_648" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_649" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_650" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_651" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_652" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_653" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_654" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_655" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_656" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_670" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_671" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_672" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_673" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_674" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_675" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_676" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_677" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_678" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_679" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_680" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_681" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_697" ,  2.25936e-01));
    this->epsilon.insert(pair<string, double>("opls_698" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_699" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_700" ,  3.17984e-01));
    this->epsilon.insert(pair<string, double>("opls_701" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_702" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_703" ,  2.51040e-01));
    this->epsilon.insert(pair<string, double>("opls_704" ,  2.25936e-01));
    this->epsilon.insert(pair<string, double>("opls_705" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_706" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_707" ,  1.67360e-01));
    this->epsilon.insert(pair<string, double>("opls_708" ,  3.17984e-01));
    this->epsilon.insert(pair<string, double>("opls_709" ,  1.25520e+00));
    this->epsilon.insert(pair<string, double>("opls_710" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_711" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_712" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_713" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_714" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_715" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_716" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_717" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_718" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_719" ,  2.55224e-01));
    this->epsilon.insert(pair<string, double>("opls_720" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_721" ,  2.55224e-01));
    this->epsilon.insert(pair<string, double>("opls_722" ,  1.96648e+00));
    this->epsilon.insert(pair<string, double>("opls_724" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_725" ,  2.59408e-01));
    this->epsilon.insert(pair<string, double>("opls_726" ,  2.55224e-01));
    this->epsilon.insert(pair<string, double>("opls_727" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_728" ,  2.55224e-01));
    this->epsilon.insert(pair<string, double>("opls_729" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_730" ,  1.96648e+00));
    this->epsilon.insert(pair<string, double>("opls_731" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_732" ,  2.42672e+00));
    this->epsilon.insert(pair<string, double>("opls_733" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_734" ,  1.04600e+00));
    this->epsilon.insert(pair<string, double>("opls_735" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_736" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_737" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_738" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_739" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_740" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_741" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_742" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_743" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_744" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_745" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_746" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_747" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_748" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_749" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_750" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_751" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_752" ,  2.09200e-01));
    this->epsilon.insert(pair<string, double>("opls_753" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_754" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_755" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_756" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_757" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_758" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_759" ,  6.27600e-02));
    this->epsilon.insert(pair<string, double>("opls_760" ,  5.02080e-01));
    this->epsilon.insert(pair<string, double>("opls_761" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_762" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_763" ,  6.27600e-02));
    this->epsilon.insert(pair<string, double>("opls_764" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_765" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_766" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_767" ,  5.02080e-01));
    this->epsilon.insert(pair<string, double>("opls_768" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_771" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_772" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_773" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_774" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_775" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_776" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_777" ,  6.27600e-02));
    this->epsilon.insert(pair<string, double>("opls_778" ,  6.27600e-02));
    this->epsilon.insert(pair<string, double>("opls_779" ,  6.27600e-02));
    this->epsilon.insert(pair<string, double>("opls_781" ,  8.36800e-01));
    this->epsilon.insert(pair<string, double>("opls_782" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_783" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_784" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_785" ,  8.36800e-01));
    this->epsilon.insert(pair<string, double>("opls_786" ,  2.55224e-01));
    this->epsilon.insert(pair<string, double>("opls_787" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_788" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_795" ,  5.85760e-01));
    this->epsilon.insert(pair<string, double>("opls_796" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_797" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_900" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_901" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_902" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_903" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_904" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_905" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_906" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_906B",  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_907" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_908" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_909" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_910" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_911" ,  6.27600e-02));
    this->epsilon.insert(pair<string, double>("opls_912" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_912B",  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_913" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_914" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_915" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_916" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_917" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_918" ,  2.92880e-01));
    this->epsilon.insert(pair<string, double>("opls_925" ,  3.59824e-01));
    this->epsilon.insert(pair<string, double>("opls_926" ,  6.27600e-02));
    this->epsilon.insert(pair<string, double>("opls_927" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_928" ,  5.64840e-01));
    this->epsilon.insert(pair<string, double>("opls_929" ,  4.18400e-01));
    this->epsilon.insert(pair<string, double>("opls_930" ,  6.27600e-02));
    this->epsilon.insert(pair<string, double>("opls_931" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_940" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_941" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_942" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_943" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_944" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_945" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_950" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_951" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_952" ,  4.39320e-01));
    this->epsilon.insert(pair<string, double>("opls_953" ,  7.11280e-01));
    this->epsilon.insert(pair<string, double>("opls_954" ,  8.78640e-01));
    this->epsilon.insert(pair<string, double>("opls_955" ,  0.00000e+00));
    this->epsilon.insert(pair<string, double>("opls_956" ,  2.55224e-01));
    this->epsilon.insert(pair<string, double>("opls_957" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_958" ,  1.25520e-01));
    this->epsilon.insert(pair<string, double>("opls_959" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_960" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_961" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_962" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_963" ,  2.76144e-01));
    this->epsilon.insert(pair<string, double>("opls_964" ,  4.05848e-01));
    this->epsilon.insert(pair<string, double>("opls_965" ,  2.21752e-01));
    //OPLS Sigma
    this->sigma.insert(pair<string, double>("opls_001" ,   3.75000e-01));
    this->sigma.insert(pair<string, double>("opls_002" ,   2.96000e-01));
    this->sigma.insert(pair<string, double>("opls_003" ,   3.25000e-01));
    this->sigma.insert(pair<string, double>("opls_004" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_005" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_006" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_007" ,   3.91000e-01));
    this->sigma.insert(pair<string, double>("opls_008" ,   3.85000e-01));
    this->sigma.insert(pair<string, double>("opls_009" ,   3.90500e-01));
    this->sigma.insert(pair<string, double>("opls_010" ,   3.90500e-01));
    this->sigma.insert(pair<string, double>("opls_011" ,   3.75000e-01));
    this->sigma.insert(pair<string, double>("opls_012" ,   3.25000e-01));
    this->sigma.insert(pair<string, double>("opls_013" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_014" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_015" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_016" ,   3.90500e-01));
    this->sigma.insert(pair<string, double>("opls_017" ,   3.75000e-01));
    this->sigma.insert(pair<string, double>("opls_018" ,   2.96000e-01));
    this->sigma.insert(pair<string, double>("opls_019" ,   3.90500e-01));
    this->sigma.insert(pair<string, double>("opls_020" ,   3.25000e-01));
    this->sigma.insert(pair<string, double>("opls_021" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_022" ,   3.90500e-01));
    this->sigma.insert(pair<string, double>("opls_023" ,   3.07000e-01));
    this->sigma.insert(pair<string, double>("opls_024" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_025" ,   3.85000e-01));
    this->sigma.insert(pair<string, double>("opls_026" ,   3.75000e-01));
    this->sigma.insert(pair<string, double>("opls_027" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_028" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_029" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_030" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_031" ,   3.90500e-01));
    this->sigma.insert(pair<string, double>("opls_032" ,   3.55000e-01));
    this->sigma.insert(pair<string, double>("opls_033" ,   0.00000e+00)); 
    this->sigma.insert(pair<string, double>("opls_034" ,   3.80000e-01));  
    this->sigma.insert(pair<string, double>("opls_035" ,   3.55000e-01));
    this->sigma.insert(pair<string, double>("opls_036" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_037" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_038" ,   3.55000e-01));
    this->sigma.insert(pair<string, double>("opls_039" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_040" ,   3.25000e-01));
    this->sigma.insert(pair<string, double>("opls_041" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_042" ,   3.25000e-01));
    this->sigma.insert(pair<string, double>("opls_043" ,   3.75000e-01));
    this->sigma.insert(pair<string, double>("opls_044" ,   3.75000e-01));
    this->sigma.insert(pair<string, double>("opls_045" ,   3.75000e-01));
    this->sigma.insert(pair<string, double>("opls_046" ,   3.25000e-01));
    this->sigma.insert(pair<string, double>("opls_047" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_048" ,   3.75000e-01));
    this->sigma.insert(pair<string, double>("opls_049" ,   3.75000e-01));
    this->sigma.insert(pair<string, double>("opls_050" ,   3.75000e-01));
    this->sigma.insert(pair<string, double>("opls_051" ,   3.25000e-01));
    this->sigma.insert(pair<string, double>("opls_052" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_053" ,   2.25000e-01));
    this->sigma.insert(pair<string, double>("opls_054" ,   3.25000e-01));
    this->sigma.insert(pair<string, double>("opls_055" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_056" ,   3.90500e-01));
    this->sigma.insert(pair<string, double>("opls_057" ,   3.90500e-01));
    this->sigma.insert(pair<string, double>("opls_058" ,   3.75000e-01));
    this->sigma.insert(pair<string, double>("opls_059" ,   2.96000e-01));
    this->sigma.insert(pair<string, double>("opls_060" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_061" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_062" ,   3.00000e-01));
    this->sigma.insert(pair<string, double>("opls_063" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_064" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_065" ,   3.96000e-01));
    this->sigma.insert(pair<string, double>("opls_066" ,   3.73000e-01));
    this->sigma.insert(pair<string, double>("opls_067" ,   3.77500e-01));
    this->sigma.insert(pair<string, double>("opls_068" ,   3.90500e-01));
    this->sigma.insert(pair<string, double>("opls_069" ,   3.91000e-01));
    this->sigma.insert(pair<string, double>("opls_070" ,   3.96000e-01));
    this->sigma.insert(pair<string, double>("opls_071" ,   3.90500e-01));
    this->sigma.insert(pair<string, double>("opls_072" ,   3.85000e-01));
    this->sigma.insert(pair<string, double>("opls_073" ,   3.85000e-01));
    this->sigma.insert(pair<string, double>("opls_074" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_075" ,   3.75000e-01));
    this->sigma.insert(pair<string, double>("opls_076" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_077" ,   3.75000e-01));
    this->sigma.insert(pair<string, double>("opls_078" ,   3.07000e-01));
    this->sigma.insert(pair<string, double>("opls_079" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_080" ,   3.77500e-01));
    this->sigma.insert(pair<string, double>("opls_081" ,   3.90500e-01));
    this->sigma.insert(pair<string, double>("opls_082" ,   3.70000e-01));
    this->sigma.insert(pair<string, double>("opls_083" ,   3.55000e-01));
    this->sigma.insert(pair<string, double>("opls_084" ,   3.55000e-01));
    this->sigma.insert(pair<string, double>("opls_085" ,   3.55000e-01));
    this->sigma.insert(pair<string, double>("opls_086" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_087" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_088" ,   3.77500e-01));
    this->sigma.insert(pair<string, double>("opls_089" ,   3.90500e-01));
    this->sigma.insert(pair<string, double>("opls_090" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_091" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_092" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_093" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_094" ,   3.20000e-01));
    this->sigma.insert(pair<string, double>("opls_095" ,   3.65000e-01));
    this->sigma.insert(pair<string, double>("opls_096" ,   3.77500e-01));
    this->sigma.insert(pair<string, double>("opls_097" ,   3.40100e-01));
    this->sigma.insert(pair<string, double>("opls_098" ,   3.93500e-01));
    this->sigma.insert(pair<string, double>("opls_099" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_101" ,   3.25000e-01));
    this->sigma.insert(pair<string, double>("opls_102" ,   3.25000e-01));
    this->sigma.insert(pair<string, double>("opls_103" ,   3.25000e-01));
    this->sigma.insert(pair<string, double>("opls_104" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_105" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_106" ,   3.77500e-01));
    this->sigma.insert(pair<string, double>("opls_107" ,   3.96000e-01));
    this->sigma.insert(pair<string, double>("opls_108" ,   3.00000e-01));
    this->sigma.insert(pair<string, double>("opls_109" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_110" ,   3.80000e-01));
    this->sigma.insert(pair<string, double>("opls_111" ,   3.15061e-01));
    this->sigma.insert(pair<string, double>("opls_112" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_113" ,   3.15365e-01));
    this->sigma.insert(pair<string, double>("opls_114" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_115" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_116" ,   3.16557e-01));
    this->sigma.insert(pair<string, double>("opls_117" ,   0.00000e+00));
    this->sigma.insert(pair<string, double>("opls_118" ,   3.12000e-01));  
    this->sigma.insert(pair<string, double>("opls_118e",   3.09700e-01));  
    this->sigma.insert(pair<string, double>("opls_119" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_120" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_122" ,   3.80000e-01));  
    this->sigma.insert(pair<string, double>("opls_123" ,   3.47000e-01));  
    this->sigma.insert(pair<string, double>("opls_124" ,   3.56000e-01));  
    this->sigma.insert(pair<string, double>("opls_125" ,   2.93000e-01));  
    this->sigma.insert(pair<string, double>("opls_126" ,   3.81000e-01));  
    this->sigma.insert(pair<string, double>("opls_127" ,   3.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_128" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_129" ,   2.78000e-01));  
    this->sigma.insert(pair<string, double>("opls_130" ,   2.55600e-01));  
    this->sigma.insert(pair<string, double>("opls_131" ,   3.80000e-01));  
    this->sigma.insert(pair<string, double>("opls_132" ,   3.80000e-01));  
    this->sigma.insert(pair<string, double>("opls_135" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_136" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_137" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_138" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_139" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_140" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_141" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_142" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_143" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_144" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_145" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_145B",   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_146" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_147" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_148" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_149" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_150" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_151" ,   3.40000e-01));  
    this->sigma.insert(pair<string, double>("opls_152" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_153" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_154" ,   3.12000e-01));  
    this->sigma.insert(pair<string, double>("opls_155" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_156" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_157" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_158" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_159" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_160" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_161" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_162" ,   3.07000e-01));  
    this->sigma.insert(pair<string, double>("opls_163" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_164" ,   2.94000e-01));  
    this->sigma.insert(pair<string, double>("opls_165" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_166" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_167" ,   3.07000e-01));  
    this->sigma.insert(pair<string, double>("opls_168" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_169" ,   3.07000e-01));  
    this->sigma.insert(pair<string, double>("opls_170" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_171" ,   3.07000e-01));  
    this->sigma.insert(pair<string, double>("opls_172" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_173" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_174" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_175" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_176" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_178" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_179" ,   2.90000e-01));  
    this->sigma.insert(pair<string, double>("opls_180" ,   2.90000e-01));  
    this->sigma.insert(pair<string, double>("opls_181" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_182" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_183" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_184" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_185" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_186" ,   2.90000e-01));  
    this->sigma.insert(pair<string, double>("opls_187" ,   3.07000e-01));  
    this->sigma.insert(pair<string, double>("opls_188" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_189" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_190" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_191" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_192" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_193" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_194" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_195" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_196" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_197" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_198" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_199" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_200" ,   3.60000e-01));  
    this->sigma.insert(pair<string, double>("opls_201" ,   3.70000e-01));  
    this->sigma.insert(pair<string, double>("opls_202" ,   3.60000e-01));  
    this->sigma.insert(pair<string, double>("opls_203" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_204" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_205" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_206" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_207" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_208" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_209" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_210" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_211" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_212" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_213" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_214" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_215" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_216" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_217" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_218" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_219" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_220" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_221" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_222" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_223" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_223B",   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_224" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_224B",   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_225" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_225B",   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_226" ,   3.40000e-01));  
    this->sigma.insert(pair<string, double>("opls_227" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_228" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_229" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_230" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_231" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_232" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_233" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_234" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_235" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_236" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_237" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_238" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_239" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_240" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_241" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_242" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_243" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_244" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_245" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_246" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_247" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_248" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_249" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_250" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_251" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_252" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_253" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_254" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_255" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_256" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_257" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_258" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_259" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_260" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_261" ,   3.65000e-01));  
    this->sigma.insert(pair<string, double>("opls_262" ,   3.20000e-01));  
    this->sigma.insert(pair<string, double>("opls_263" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_264" ,   3.40000e-01));  
    this->sigma.insert(pair<string, double>("opls_265" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_266" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_267" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_268" ,   3.00000e-01));  
    this->sigma.insert(pair<string, double>("opls_269" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_270" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_271" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_272" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_273" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_274" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_275" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_276" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_277" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_278" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_279" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_280" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_281" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_282" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_283" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_284" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_285" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_286" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_287" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_288" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_289" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_290" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_291" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_292" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_292B",   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_293" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_293B",   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_294" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_295" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_296" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_297" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_298" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_299" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_300" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_301" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_302" ,   2.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_303" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_304" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_305" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_306" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_307" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_308" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_309" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_310" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_311" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_312" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_313" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_314" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_315" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_316" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_317" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_318" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_319" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_319B",   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_320" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_321" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_322" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_323" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_324" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_325" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_326" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_327" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_328" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_329" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_330" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_331" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_332" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_333" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_333B",   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_334" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_335" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_336" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_337" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_338" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_339" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_340" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_341" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_342" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_343" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_344" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_345" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_346" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_347" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_348" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_349" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_350" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_351" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_352" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_353" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_354" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_354B",   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_355" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_356" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_357" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_358" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_359" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_360" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_361" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_362" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_363" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_364" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_365" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_366" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_367" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_368" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_369" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_370" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_371" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_372" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_373" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_374" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_375" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_376" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_377" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_377B",   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_378" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_379" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_380" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_381" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_382" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_383" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_384" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_385" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_386" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_387" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_388" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_389" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_390" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_391" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_392" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_393" ,   3.74000e-01));  
    this->sigma.insert(pair<string, double>("opls_394" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_395" ,   3.00000e-01));  
    this->sigma.insert(pair<string, double>("opls_396" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_400" ,   2.73295e-01));  
    this->sigma.insert(pair<string, double>("opls_401" ,   4.41724e-01));  
    this->sigma.insert(pair<string, double>("opls_402" ,   4.62376e-01));  
    this->sigma.insert(pair<string, double>("opls_403" ,   5.40000e-01));  
    this->sigma.insert(pair<string, double>("opls_404" ,   1.25992e-01));  
    this->sigma.insert(pair<string, double>("opls_405" ,   1.89744e-01));  
    this->sigma.insert(pair<string, double>("opls_406" ,   2.12645e-01));  
    this->sigma.insert(pair<string, double>("opls_407" ,   3.33045e-01));  
    this->sigma.insert(pair<string, double>("opls_408" ,   4.93463e-01));  
    this->sigma.insert(pair<string, double>("opls_409" ,   5.62177e-01));  
    this->sigma.insert(pair<string, double>("opls_410" ,   6.71600e-01));  
    this->sigma.insert(pair<string, double>("opls_411" ,   1.64447e-01));  
    this->sigma.insert(pair<string, double>("opls_412" ,   2.41203e-01));  
    this->sigma.insert(pair<string, double>("opls_413" ,   3.10269e-01));  
    this->sigma.insert(pair<string, double>("opls_414" ,   3.81661e-01)); 
    this->sigma.insert(pair<string, double>("opls_415" ,   4.20000e-01));  
    this->sigma.insert(pair<string, double>("opls_416" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_417" ,   4.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_418" ,   4.20000e-01));  
    this->sigma.insert(pair<string, double>("opls_419" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_420" ,   3.15000e-01));  
    this->sigma.insert(pair<string, double>("opls_421" ,   4.20000e-01));  
    this->sigma.insert(pair<string, double>("opls_422" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_423" ,   3.65000e-01));  
    this->sigma.insert(pair<string, double>("opls_424" ,   3.40000e-01));  
    this->sigma.insert(pair<string, double>("opls_425" ,   4.20000e-01));  
    this->sigma.insert(pair<string, double>("opls_426" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_427" ,   3.40000e-01));  
    this->sigma.insert(pair<string, double>("opls_428" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_429" ,   4.20000e-01));  
    this->sigma.insert(pair<string, double>("opls_430" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_431" ,   4.20000e-01));  
    this->sigma.insert(pair<string, double>("opls_432" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_433" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_434" ,   3.20000e-01));  
    this->sigma.insert(pair<string, double>("opls_435" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_436" ,   2.81524e-01));  
    this->sigma.insert(pair<string, double>("opls_437" ,   3.11815e-01));  
    this->sigma.insert(pair<string, double>("opls_440" ,   3.74000e-01));  
    this->sigma.insert(pair<string, double>("opls_441" ,   3.15000e-01));  
    this->sigma.insert(pair<string, double>("opls_442" ,   2.90000e-01));  
    this->sigma.insert(pair<string, double>("opls_443" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_444" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_445" ,   3.74000e-01));  
    this->sigma.insert(pair<string, double>("opls_446" ,   3.15000e-01));  
    this->sigma.insert(pair<string, double>("opls_447" ,   2.90000e-01));  
    this->sigma.insert(pair<string, double>("opls_448" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_449" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_450" ,   3.74000e-01));  
    this->sigma.insert(pair<string, double>("opls_451" ,   3.15000e-01));  
    this->sigma.insert(pair<string, double>("opls_452" ,   2.90000e-01));  
    this->sigma.insert(pair<string, double>("opls_453" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_454" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_455" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_456" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_457" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_458" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_459" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_460" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_461" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_462" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_463" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_465" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_466" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_467" ,   3.00000e-01));  
    this->sigma.insert(pair<string, double>("opls_468" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_469" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_470" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_471" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_472" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_473" ,   3.00000e-01));  
    this->sigma.insert(pair<string, double>("opls_474" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_475" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_476" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_477" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_478" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_479" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_480" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_481" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_482" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_483" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_484" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_485" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_486" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_487" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_488" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_490" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_491" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_492" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_493" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_494" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_496" ,   3.56000e-01));  
    this->sigma.insert(pair<string, double>("opls_497" ,   2.93000e-01));  
    this->sigma.insert(pair<string, double>("opls_498" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_499" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_500" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_501" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_502" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_503" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_504" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_505" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_506" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_507" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_508" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_509" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_510" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_511" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_512" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_513" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_514" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_515" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_516" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_517" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_518" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_520" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_521" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_522" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_523" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_524" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_525" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_526" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_527" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_528" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_529" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_530" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_531" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_532" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_533" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_534" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_535" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_536" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_537" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_538" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_539" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_540" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_541" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_542" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_543" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_544" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_545" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_546" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_547" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_548" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_549" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_550" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_551" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_552" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_553" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_554" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_555" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_556" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_557" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_558" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_559" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_560" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_561" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_562" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_563" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_564" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_565" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_566" ,   2.90000e-01));  
    this->sigma.insert(pair<string, double>("opls_567" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_568" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_569" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_570" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_571" ,   2.90000e-01));  
    this->sigma.insert(pair<string, double>("opls_572" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_573" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_574" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_575" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_576" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_577" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_578" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_579" ,   2.90000e-01));  
    this->sigma.insert(pair<string, double>("opls_580" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_581" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_582" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_583" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_584" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_585" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_586" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_587" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_588" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_589" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_590" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_591" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_592" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_593" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_594" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_595" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_596" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_597" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_598" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_599" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_600" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_601" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_602" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_603" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_604" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_605" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_606" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_607" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_608" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_609" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_610" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_611" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_612" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_613" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_614" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_615" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_616" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_617" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_618" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_619" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_620" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_621" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_622" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_623" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_624" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_625" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_626" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_627" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_628" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_629" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_630" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_631" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_632" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_633" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_634" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_635" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_636" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_637" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_638" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_639" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_640" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_641" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_642" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_643" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_644" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_645" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_646" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_647" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_648" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_649" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_650" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_651" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_652" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_653" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_654" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_655" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_656" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_670" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_671" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_672" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_673" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_674" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_675" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_676" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_677" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_678" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_679" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_680" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_681" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_697" ,   3.47300e-01));  
    this->sigma.insert(pair<string, double>("opls_698" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_699" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_700" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_701" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_702" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_703" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_704" ,   3.47300e-01));  
    this->sigma.insert(pair<string, double>("opls_705" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_706" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_707" ,   2.95000e-01));  
    this->sigma.insert(pair<string, double>("opls_708" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_709" ,   3.40000e-01));  
    this->sigma.insert(pair<string, double>("opls_710" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_711" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_712" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_713" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_714" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_715" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_716" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_717" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_718" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_719" ,   2.85000e-01));  
    this->sigma.insert(pair<string, double>("opls_720" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_721" ,   2.85000e-01));  
    this->sigma.insert(pair<string, double>("opls_722" ,   3.47000e-01));  
    this->sigma.insert(pair<string, double>("opls_724" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_725" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_726" ,   2.94000e-01));  
    this->sigma.insert(pair<string, double>("opls_727" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_728" ,   2.85000e-01));  
    this->sigma.insert(pair<string, double>("opls_729" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_730" ,   3.47000e-01));  
    this->sigma.insert(pair<string, double>("opls_731" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_732" ,   3.67000e-01));  
    this->sigma.insert(pair<string, double>("opls_733" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_734" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_735" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_736" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_737" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_738" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_739" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_740" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_741" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_742" ,   2.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_743" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_744" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_745" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_746" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_747" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_748" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_749" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_750" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_751" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_752" ,   2.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_753" ,   3.20000e-01));  
    this->sigma.insert(pair<string, double>("opls_754" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_755" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_756" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_757" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_758" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_759" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_760" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_761" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_762" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_763" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_764" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_765" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_766" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_767" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_768" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_771" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_772" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_773" ,   3.00000e-01));  
    this->sigma.insert(pair<string, double>("opls_774" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_775" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_776" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_777" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_778" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_779" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_781" ,   3.74000e-01));  
    this->sigma.insert(pair<string, double>("opls_782" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_783" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_784" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_785" ,   3.74000e-01));  
    this->sigma.insert(pair<string, double>("opls_786" ,   3.11810e-01));  
    this->sigma.insert(pair<string, double>("opls_787" ,   3.15000e-01));  
    this->sigma.insert(pair<string, double>("opls_788" ,   2.86000e-01));  
    this->sigma.insert(pair<string, double>("opls_795" ,   3.21500e-01));  
    this->sigma.insert(pair<string, double>("opls_796" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_797" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_900" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_901" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_902" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_903" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_904" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_905" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_906" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_906B",   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_907" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_908" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_909" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_910" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_911" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_912" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_912B",   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_913" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_914" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_915" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_916" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_917" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_918" ,   3.55000e-01));  
    this->sigma.insert(pair<string, double>("opls_925" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_926" ,   2.42000e-01));  
    this->sigma.insert(pair<string, double>("opls_927" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_928" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_929" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_930" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_931" ,   3.30000e-01));  
    this->sigma.insert(pair<string, double>("opls_940" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_941" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_942" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_943" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_944" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_945" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_950" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_951" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_952" ,   3.75000e-01));  
    this->sigma.insert(pair<string, double>("opls_953" ,   3.25000e-01));  
    this->sigma.insert(pair<string, double>("opls_954" ,   2.96000e-01));  
    this->sigma.insert(pair<string, double>("opls_955" ,   0.00000e+00));  
    this->sigma.insert(pair<string, double>("opls_956" ,   2.94000e-01));  
    this->sigma.insert(pair<string, double>("opls_957" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_958" ,   2.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_959" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_960" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_961" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_962" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_963" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_964" ,   3.50000e-01));  
    this->sigma.insert(pair<string, double>("opls_965" ,   2.95000e-01));


};

OPLSff::~OPLSff(){
    this->opls.clear();
    this->epsilon.clear();
    this->sigma.clear();
};   

string OPLSff::getBondType(string opls_str){
    return this->opls[opls_str];
};

double OPLSff::getEpsilon(string opls_str){
    return this->epsilon[opls_str];
};

double OPLSff::getSigma(string opls_str){
    return this->sigma[opls_str];
};


